package geniusweb.profileconnection;

import java.io.IOException;
import java.net.URI;

import javax.websocket.ContainerProvider;
import javax.websocket.DeploymentException;

import geniusweb.profile.Profile;
import tudelft.utilities.logging.Reporter;

/**
 * factory that provides a ProfileInterface given an URI, supporting both the ws
 * and the file scheme for the uri
 */
public class ProfileConnectionFactory {

	/**
	 * @param uri      the URI that can provide the {@link Profile}. Support
	 *                 both the ws and the file scheme for the uri.
	 * @param reporter the {@link Reporter} to log issues to
	 * @return a {@link ProfileInterface}
	 * @throws IOException         if connection can't be made
	 * @throws DeploymentException if endpoint can't be published
	 */
	public static ProfileInterface create(URI uri, Reporter reporter)
			throws IOException, DeploymentException {
		switch (uri.getScheme()) {
		case "ws":
			return new WebsocketProfileConnector(uri, reporter,
					ContainerProvider.getWebSocketContainer());
		case "file":
			return new FileProfileConnector(uri.getSchemeSpecificPart());
		default:
		}
		throw new IllegalArgumentException(
				"Unsupported profile scheme " + uri.getScheme());
	}

}
